Coverage for /home/chris/workspace/django-shop/shop/models/productmodel: 100.00%

# Coverage for /home/chris/workspace/django-shop/shop/models/productmodel : 100.00%

## 4 statements 4 run 0 missing 0 excluded 0 partial

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 | # -*- coding: utf-8 -*- from django.conf import settings from shop.util.loader import load_class #=============================================================================== # Extensibility #=============================================================================== """ This overrides the Product model with the class loaded from the SHOP_PRODUCT_MODEL setting if it exists. """ PRODUCT_MODEL = getattr(settings, 'SHOP_PRODUCT_MODEL', 'shop.models.defaults.product.Product') Product = load_class(PRODUCT_MODEL, 'SHOP_PRODUCT_MODEL')